@@ -1,33 +1,38 @@
 from python_helper import TestHelper
-# TestHelper.run(__file__, inspectGlobals=False)
-
+TestHelper.run(__file__, inspectGlobals=False)
 # TestHelper.run(
 #     __file__,
 #     runOnly = [
-#         'DateTimeHelperTest.plusYears',
-#         'DateTimeHelperTest.minusYears'
+#         # 'ObjectHelperTest.basicMethods'
+#         # , 'ObjectHelperTest.mustAssertEquals'
+#         # , 'ObjectHelperTest.mustIgnoreKeyCorrectly'
+#         # , 'ObjectHelperTest.equal_whenListOfDictionaries_ignoreCollectionOrder'
+#         # , 'ObjectHelperTest.equal_whenObjects'
+#         # , 'ObjectHelperTest.sortIt'
+#         # , 'ObjectHelperTest.sortIt_whenNotEquals'
+#         # # , 'ObjectHelperTest.sortIt_whenSortedVisitedIdInstances'
+#         # , 'ObjectHelperTest.equals_whenNotEquals_simpleSet'
+#         # , 'ObjectHelperTest.equal_whenDictionary'
+#         # , 'ObjectHelperTest.equal_whenSets'
+#         # , 'ObjectHelperTest.equal_whenRecursive'
+#         'ObjectHelperTest.equals_whenDateTime'
+#     ]
+# )
+# TestHelper.run(
+#     __file__,
+#     runOnly = [
+#         'ReflectionHelperTest.getCompleteInstanceNameList'
+#         , 'ReflectionHelperTest.getInstanceNameList'
+#         , 'ReflectionHelperTest.getInstanceName'
+#         , 'ReflectionHelperTest.getInstanceName_whenExpression'
+#     ]
+# )
+# TestHelper.run(
+#     __file__,
+#     runOnly = [
+#         'DateTimeHelperTest.isNativeDateTime'
 #     ]
 # )
-TestHelper.run(
-    __file__,
-    runOnly = [
-        # 'ObjectHelperTest.basicMethods'
-        # , 'ObjectHelperTest.mustAssertEquals'
-        # , 'ObjectHelperTest.mustIgnoreKeyCorrectly'
-        # , 'ObjectHelperTest.equal_whenListOfDictionaries_ignoreCollectionOrder'
-        # , 'ObjectHelperTest.equal_whenObjects'
-        # , 'ObjectHelperTest.sortIt'
-        # , 'ObjectHelperTest.sortIt_whenNotEquals'
-        # # , 'ObjectHelperTest.sortIt_whenSortedVisitedIdInstances'
-        # , 'ObjectHelperTest.equals_whenNotEquals_simpleSet'
-        # , 'ObjectHelperTest.equal_whenDictionary'
-        # , 'ObjectHelperTest.equal_whenSets'
-        'ObjectHelperTest.getCompleteInstanceNameList'
-        , 'ObjectHelperTest.getInstanceNameList'
-        , 'ObjectHelperTest.getInstanceName'
-        # , 'ObjectHelperTest.equal_whenRecursive'
-    ]
-)
 # TestHelper.run(
 #     __file__,
 #     runOnly = [
