@@ -38,6 +38,20 @@ DEFAULT_TIME_BEGIN = '00:00:00'
 DEFAULT_TIME_END = '23:59:59'
 
 
+def isDateTime(givenDatetime):
+    return (
+        isNativeDateTime(givenDatetime) or
+        (
+            isinstance(givenDatetime, str) and
+            isinstance(of(givenDatetime), datetime.datetime)
+        )
+    )
+
+
+def isNativeDateTime(givenDatetime):
+    return isinstance(givenDatetime, datetime.datetime)
+
+
 def toString(givenDatetime, pattern=DEFAULT_DATETIME_PATTERN):
     return givenDatetime if ObjectHelper.isNone(givenDatetime) or isinstance(givenDatetime, str) else parseToString(givenDatetime, pattern=pattern)
 
